package sgraphics;

// Copyright (c) 1987-91 Stanford University
// Copyright (c) 1991-94 Silicon Graphics, Inc.
// Copyright (c) 1993-94 Fujitsu, Ltd.
// Copyright (c) 1996    Michael A. Jones

import java.util.*;

/**
 * An adjustment is two segments that represent the possible and
 * current range of values for a bounded value, such as would
 * be used for scrolling.<p>
 * Adjustment supports transactions. Calls made outside a
 * transaction take affect immediately.
 */
public abstract class Adjustment extends Observable {

    /**
     * Begin a transaction.
     */
    public abstract void begin ();

    /**
     * End a transaction.
     */
    public abstract void commit ();

    /**
     * Cancel a transaction.
     */
    public abstract void cancel ();

	/**
	 * Set the constraint used to constrain the scroll region.
     */
    public abstract void setAdjustmentConstraint (AdjustmentConstraint constraint);

	/**
	 * Get the constraint used to constrain the scroll region.
     */
    public abstract AdjustmentConstraint getAdjustmentConstraint ();

    /**
     * Modify the given coordinate if necessary to keep
	 * it within the adjustment's settings.  If the given
	 * value is below the adjustment's lower bound, then
	 * set it to the lower bound.  If the given value
	 * plus the current length is large than the adjustment's
	 * upper bound, then set it to be the upper bound minus
	 * the current length.
     */
    public abstract float constrain (float constraint);

    /**
     * Retrieve the current settings of the adjustment.
     */
    public abstract AdjustmentSettings getSettings ();

	/**
	 * Request that the adjustment change its current length,
	 * effectively scaling the adjustment so that it covers
	 * more or less of the total segment.
     */
    public abstract void scaleTo (float length);

	/**
	 * Request that the adjustment change its lower position
	 * to add the given delta (which may be negative).
	 */
    public abstract void scrollBy (float delta);

    public abstract void scrollForward ();
    public abstract void scrollBackward();
    public abstract void pageForward ();
    public abstract void pageBackward ();
    public abstract void scrollBegin ();
    public abstract void scrollEnd();

	/**
	 * Request that the adjustment change its lower position
	 * to the given coordinate.
	 */
    public abstract void scrollTo (float lower);

    /**
     * Set the scroll forward and backward ammount.
     */
    public abstract void setSmallScroll (float size);

    /**
     * Get the scroll forward and backward ammount.
     */
    public abstract float getSmallScroll ();

    /**
     * Set the page forward and backward ammount.
     */
    public abstract void setLargeScroll (float size);

    /**
     * Get the page forward and backward ammount.
     */
    public abstract float getLargeScroll ();
}
