package sgraphics;

// Copyright (c) 1987-91 Stanford University
// Copyright (c) 1991-95 Silicon Graphics, Inc.
// Copyright (c) 1993-95 2001 S.A.
// Copyright (c) 1993-96 Fujitsu, Ltd.
// Copyright (c) 1994-96 Firefly Design
// Copyright (c) 1995-96 Vitria, Inc.
// Copyright (c) 1996    Michael A. Jones
// Copyright (c) 1997    Bill Petheram

import java.awt.Graphics;

public class DebugGlyph extends MonoGlyph {
	private Glyph body_ = null;

	public DebugGlyph () {
		}

	public DebugGlyph (Glyph body) {
		body_ = body;
		body_.setParent(this);
		}

    public Requirements requirements () {
		if (body_ != null) {
			System.out.println("DEBUG: requirements");
			Requirements r = body_.requirements();
			Requirement x = r.x;
			Requirement y = r.y;
			System.out.println("DEBUG: requirement x is natural = " + x.natural + " maximum = " + x.maximum + " minimum = " + x.minimum + " alignment = " + x.align);
			System.out.println("DEBUG: requirement y is natural = " + y.natural + " maximum = " + y.maximum + " minimum = " + y.minimum + " alignment = " + y.align);
			return r;
			}
		else
			return null;
		}

    public void allocate (Allocation allocation) {
		if (body_ != null) {
			System.out.println("DEBUG: allocate");
			body_.allocate(allocation);
			Area a = allocation.allocation;
			BoundingSpan x = a.span(Area.xAxis);
			BoundingSpan y = a.span(Area.yAxis);
			System.out.println("DEBUG: allocate x is begin = " + x.begin + " end = " + x.end + " length = " + x.length + " align " + x.align);
			System.out.println("DEBUG: allocate y is begin = " + y.begin + " end = " + y.end + " length = " + y.length + " align " + y.align);

			}
		}

	public void pick (Picker pick) {
		System.out.println("handle");
		if (body_ != null) {
			System.out.println("DEBUG: forward call");
			body_.pick(pick);
			}
		}

	public Glyph body () {
		System.out.println("DEBUG: body");
		return body_;
		}

	public void setBody (Glyph body) {
		System.out.println("DEBUG: setBody");
		if (body_ != null) {
			System.out.println("DEBUG: setParent null");
			body_.setParent(null);
			}
		body_ = body;
		body_.setParent(this);
		}

	public void append (Glyph glyph) {
		System.out.println("DEBUG: append");
		if (body_ != null)
			System.out.println("DEBUG: forward call");
			body_.append(glyph);
		}

	public void prepend (Glyph glyph) {
		System.out.println("DEBUG: prepend");
		if (body_ != null)
			System.out.println("DEBUG: forward call");
			body_.prepend(glyph);
		}

	public void replace (int position, Glyph glyph) {
		System.out.println("DEBUG: prepend");
		if (body_ != null)
			System.out.println("DEBUG: forward call");
			body_.replace(position, glyph);
		}

	public void needRedraw () {
		System.out.println("DEBUG: needRedraw");
		super.needRedraw();
		}

	public void needRedraw (Area area) {
		System.out.println("DEBUG: needRedraw " + area);
		super.needRedraw(area);
		}

	public void needSize () {
		System.out.println("DEBUG: needSize");
		super.needResize();
		}

	public void draw (Painter painter) {
	    Area a = painter.getClipRect();
		System.out.println("DEBUG: draw - clip rectangle is " + a);
		if (body_ != null) {
			System.out.println("DEBUG: forward call");
			body_.draw(painter);
			}
		}

}
