package sgraphics;

// Copyright (c) 1987-91 Stanford University
// Copyright (c) 1991-95 Silicon Graphics, Inc.
// Copyright (c) 1993-95 2001 S.A.
// Copyright (c) 1993-96 Fujitsu, Ltd.
// Copyright (c) 1994-96 Firefly Design
// Copyright (c) 1995-96 Vitria, Inc.
// Copyright (c) 1996    Michael A. Jones

import java.awt.Graphics;

/**
 * The MonoGlyph class is a Proxy class for another Glyph or child of
 * a Glyph. It may be used to add functionality to a Glyph or change its
 * behavior. For example: a frame glyph around a text editor
 * glyph.
 */
public class MonoGlyph extends GlyphImpl {

	public MonoGlyph () {
	}

	public MonoGlyph (Glyph body) {
		body_ = body;
		if (body_ != null)
		    body_.setParent(this);
	}

    public Requirements requirements () {
		if (body_ != null)
			return body_.requirements();
		else
			return null;
	}

    public void allocate (Allocation allocation) {
		if (body_ != null)
			body_.allocate(allocation);
	}

    public void pick (Picker pick) {
		if (body_ != null)
			body_.pick(pick);
	}

	public void draw (Painter painter) {
		if (body_ != null)
			body_.draw(painter);
	}

	public void append (Glyph glyph) {
		if (body_ != null)
			body_.append(glyph);
	}

	public void prepend (Glyph glyph) {
		if (body_ != null)
			body_.prepend(glyph);
	}

	public void replace (int position, Glyph glyph) {
		if (body_ != null)
			body_.replace(position, glyph);
	}

    public Glyph getChild (int pos) {
		if (body_ != null)
			return body_.getChild(pos);
		else
		    return null;
	}

	public void empty () {
		if (body_ != null)
			body_.empty();
	}

	public int count () {
	    if (body_ != null)
	        return body_.count();
	    else
	        return 0;
	}
}
