package sgraphics;

// Copyright (c) 1996    Michael A. Jones

import java.awt.FontMetrics;
import java.awt.Font;
import java.awt.Toolkit;

/**
 * Utility to convert coordinates from awt ints to resolution independent
 * floats.
 */
public class Sgraphics {
    private float hFactor_;
    private float vFactor_;

    /**
     * Set this to false if resolution independent graphics is not desired.
     * Note: this will allow rounding errors that can effect tiling.
     */
    public static boolean resolutionIndependent = true;

    /**
     * Set this to false to stop Boxes from caching requirements. This can
     * help in situations with widgets when requirements() is called
     * while they are hidden (like when using a card layout).
     */
     public static boolean cacheRequirements = true;

    public Sgraphics () {
        Toolkit kit = Toolkit.getDefaultToolkit();
        float res = (float) kit.getScreenResolution();
        hFactor_ = res/72F;
        vFactor_ = res/72F;
    }
	public float convertHorizontal (int h) {
	    if (resolutionIndependent)
	        return ((float) h)/hFactor_;
	    else
	        return (float) h;
	}

	public float convertVertical (int v) {
	    if (resolutionIndependent)
	        return ((float) v)/vFactor_;
	    else
	        return (float) v;
	}

	public int convertHorizontal (float h) {
	    if (resolutionIndependent)
	        return Math.round (h * hFactor_);
	    else
	        return Math.round(h);
	}

	public int convertVertical (float v) {
	    if (resolutionIndependent)
	        return Math.round(v * vFactor_);
	    else
	        return Math.round(v);
	}
}