
package sgraphics;

// Copyright (c) 1996    Michael A. Jones
// Copyright (c) 1997    Bill Petheram

/**
 * ViewerCallback is the interface for event handling callbacks.
 */
public interface ViewerCallback {

	/**
	 * Called when the mouse is pressed.
	 * @param evt the event
	 * @param child the glyph inside the viewer that was hit.
	 * @param x the x coordinate
	 * @param y the y coordinate
	 */
	public boolean mouseDown(Viewer v, GraphicsEvent evt, float X, float Y);

	/**
	 * Called when the mouse is dragged (the mouse button is down).
	 * @param evt the event
	 * @param child the glyph inside the viewer that was hit.
	 * @param x the x coordinate
	 * @param y the y coordinate
	 */
	public boolean mouseDrag(Viewer v, GraphicsEvent evt, float X, float Y);
	/**
	 * Called when the mouse is released.
	 * @param evt the event
	 * @param child the glyph inside the viewer that was hit.
	 * @param x the x coordinate
	 * @param y the y coordinate
	 */
	public boolean mouseUp(Viewer v, GraphicsEvent evt, float X, float Y);

	/**
	 * Called when the mouse moves (the mouse button is up).
	 * @param evt the event
	 * @param child the glyph inside the viewer that was hit.
	 * @param x the x coordinate
	 * @param y the y coordinate
	 */
	public boolean mouseMove(Viewer v, GraphicsEvent evt, float X, float Y);

	/**
	 * Called when the mouse enters the component.
	 * @param evt the event
	 * @param child the glyph inside the viewer that was hit.
	 * @param x the x coordinate
	 * @param y the y coordinate
	 */
	public boolean mouseEnter(Viewer v, GraphicsEvent evt, float X, float Y);

	/**
	 * Called when the mouse exits the component.
	 * @param evt the event
	 * @param child the glyph inside the viewer that was hit.
	 * @param x the x coordinate
	 * @param y the y coordinate
	 */
	public boolean mouseExit(Viewer v, GraphicsEvent evt, float X, float Y);

	/**
	 * Called when a character is pressed.
	 * @param evt the event
	 * @param child the glyph inside the viewer that was hit.
	 * @param key the key that's pressed
	*/
	public boolean keyDown(Viewer v, GraphicsEvent evt, int key);

	/**
	 * Called when a character is released.
	 * @param evt the event
	 * @param child the glyph inside the viewer that was hit.
	 * @param key the key that's released
	 */
	public boolean keyUp(Viewer v, GraphicsEvent evt, int key);

	/**
	 * Called when an action character is pressed.
	 * @param evt the event
	 * @param child the glyph inside the viewer that was hit.
	 * @param key the key that's pressed
	*/
	public boolean keyActionDown(Viewer v, GraphicsEvent evt, int key);

	/**
	 * Called when an action character is released.
	 * @param evt the event
	 * @param child the glyph inside the viewer that was hit.
	 * @param key the key that's released
	 */
	public boolean keyActionUp(Viewer v, GraphicsEvent evt, int key);

	/**
	/**
	 * Called when an action occurs in the Component.
	 * @param evt the event
	 * @param child the glyph inside the viewer that was hit.
	 * @param what the action that's occuring
	 */
	public boolean action(Viewer v, GraphicsEvent evt, Object what);

}
