package sgraphics.example;

// Copyright (c) 1996    Michael A. Jones
// Copyright (c) 1997    Bill Petheram

import java.awt.*;
import java.applet.*;

import sgraphics.*;
import sgraphics.figure.*;
import sgraphics.layout.*;
import sgraphics.widget.*;
import sgraphics.wrapper.*;
import sgraphics.tutorial.AppletFrame;

public class CanvasEditor2 extends Applet {
    private CanvasGlyph canvas_ = new CanvasGlyph(0, 0);
    private SgraphicsAdapter adapter_;
    private ScrollbarGlyph vbar_ = new ScrollbarGlyph(ScrollbarGlyph.VERTICAL);
    private ScrollbarGlyph hbar_ = new ScrollbarGlyph(ScrollbarGlyph.HORIZONTAL);

    private Button zoomIn_ = new Button("Zoom In");
    private Button zoomOut_ = new Button("Zoom Out");
    private boolean zoomed_ = false;

    private int width_ = 1024;
    private int height_ = 1024;

    private int xOffset_ = 0;
    private int yOffset_ = 0;

    public static void main (String arg[]) {
        Applet applet = new CanvasEditor2();
        Frame frame = new AppletFrame("Canvas Editor Example", applet, 600, 600);
        frame.show();
    }

	public void init () {
		FigureStyle style = new FigureStyle();
		style.foreground = Color.green;
		style.brushSize = 1;
		Glyph oval = FigureKit.oval(FigureMode.Fill, style, 0, 0, 100, 50);
        canvas_.append(new FigureViewer(oval, new sgraphics.Point(20, 20)));

		style = new FigureStyle();
		style.foreground = Color.blue;
		style.brushSize = 6;
		Glyph rect = FigureKit.rectangle(FigureMode.Stroke, style, 0, 0, 20, 20);
        canvas_.append(new FigureViewer(rect, new sgraphics.Point(20, 20)));

		style = new FigureStyle();
		style.foreground = Color.red;
		style.brushSize = 1;
		Glyph cir = FigureKit.circle(FigureMode.Stroke, style, 0, 0, 60);
        canvas_.append(new FigureViewer(cir, new sgraphics.Point(40, 40)));

        Sgraphics s = new Sgraphics();
        Toolkit kit = Toolkit.getDefaultToolkit();
        Image image = getImage(getCodeBase(), "sgraphics/example/camera.gif");
		Figure figimage = FigureKit.image(image, s.convertHorizontal(72), s.convertVertical(72));
        canvas_.append(new FigureViewer(figimage, new sgraphics.Point(90, 90)));

		image = getImage(getCodeBase(), "sgraphics/example/gopher.gif");
		figimage = FigureKit.image(image);
        canvas_.append(new FigureViewer(figimage, new sgraphics.Point(150, 10)));

        Glyph hbox = LayoutKit.hbox();
        hbox.append(canvas_);
        hbox.append(LayoutKit.hfixed(vbar_, 15));
        Glyph vbox = LayoutKit.vbox();
        vbox.append(hbox);
        Glyph hbox2 = LayoutKit.hbox();
        hbox2.append(LayoutKit.vfixed(hbar_, 15));
        hbox2.append(LayoutKit.hspace(15));
        vbox.append(hbox2);

        adapter_ = new SgraphicsAdapter(vbox);

        GridBagLayout layout = new GridBagLayout();
        setLayout(layout);

		GridBagConstraints constraints = new GridBagConstraints();
		constraints.gridx = 0;
		constraints.gridy = 0;
		constraints.gridwidth = 1;
		constraints.gridheight = 1;
		constraints.weightx = 1;
		constraints.weighty = 1;
		constraints.fill = GridBagConstraints.BOTH;
		layout.setConstraints(adapter_, constraints);
		add(adapter_);

		Panel p = new Panel();
		p.setLayout(new FlowLayout(FlowLayout.CENTER, 20, 10));
		p.add(zoomIn_);
		p.add(zoomOut_);

		constraints.gridx = 0;
		constraints.gridy = 1;
		constraints.weightx = 0;
		constraints.weighty = 0;
		constraints.gridwidth = 1;
		constraints.fill = GridBagConstraints.HORIZONTAL;
		layout.setConstraints(p, constraints);
		add(p);
    }

	public synchronized void reshape (int x, int y, int width, int height) {
		super.reshape(x, y, width, height);

	    int w = width - vbar_.preferredSize().width;
	    int h = height - hbar_.preferredSize().height;

	    vbar_.setValues(yOffset_, h, 0, height_ - h);
	    hbar_.setValues(xOffset_, w, 0, width_ - w);
	    vbar_.setPageIncrement(h);
	    vbar_.setLineIncrement(1);
	    hbar_.setLineIncrement(1);
	    hbar_.setPageIncrement(w);
    }

    public boolean handleEvent (Event event) {
        if (event.target == vbar_ &&
            (event.id == Event.SCROLL_ABSOLUTE |
             event.id == Event.SCROLL_LINE_DOWN |
             event.id == Event.SCROLL_PAGE_DOWN |
             event.id == Event.SCROLL_LINE_UP |
             event.id == Event.SCROLL_PAGE_UP)) {
            yOffset_ = vbar_.getValue();
            canvas_.setYOffset(yOffset_);
            }
        else if (event.target == hbar_ &&
            (event.id == Event.SCROLL_ABSOLUTE |
             event.id == Event.SCROLL_LINE_DOWN |
             event.id == Event.SCROLL_PAGE_DOWN |
             event.id == Event.SCROLL_LINE_UP |
             event.id == Event.SCROLL_PAGE_UP)) {
            xOffset_ = hbar_.getValue();
            canvas_.setXOffset(xOffset_);
            }
        else if (event.target == zoomIn_ &&
                event.id == Event.ACTION_EVENT) {
            if (!zoomed_) {
                canvas_.setScale(2.0F);
                zoomed_ = true;
            }
        }
        else if (event.target == zoomOut_ &&
                event.id == Event.ACTION_EVENT) {
            if (zoomed_) {
                canvas_.setScale(1.0F);
                zoomed_ = false;
            }
        }
        return super.handleEvent(event);
    }

    public void update (Graphics g) {
        paint(g);
    }
}
