package sgraphics.example;

// Copyright (c) 1996    Michael A. Jones

import java.awt.*;
import java.applet.*;

import sgraphics.*;
import sgraphics.figure.*;
import sgraphics.layout.*;
import sgraphics.widget.*;
import sgraphics.wrapper.*;

public class CanvasEditor3 extends Frame {
    private CanvasGlyph canvas_ = new CanvasGlyph(1000, 1000);
    private Viewport viewport_ = LayoutKit.createViewport(canvas_);
    private Adjustment xAdjustment_ = viewport_.getScrollAdjustment(Viewport.xAxis);
    private Adjustment yAdjustment_ = viewport_.getScrollAdjustment(Viewport.yAxis);
    private SgraphicsAdapter adapter_;
    private ScrollbarGlyph vbar_ = new ScrollbarGlyph(ScrollbarGlyph.VERTICAL, yAdjustment_);
    private ScrollbarGlyph hbar_ = new ScrollbarGlyph(ScrollbarGlyph.HORIZONTAL, xAdjustment_);

    private Button zoomIn_ = new Button("Zoom In");
    private Button zoomOut_ = new Button("Zoom Out");
    private Button quit_ = new Button("Quit");
    private boolean zoomed_ = false;

    public CanvasEditor3 (Applet applet) {
        FigureStyle style = new FigureStyle();
        style.foreground = Color.green;
        style.brushSize = 1;
        Glyph oval = FigureKit.oval(FigureMode.Fill, style, 0, 0, 100, 50);
        canvas_.append(new FigureViewer(oval, new sgraphics.Point(20, 20)));

        style = new FigureStyle();
        style.foreground = Color.blue;
        style.brushSize = 6;
        Glyph rect = FigureKit.rectangle(FigureMode.Stroke, style, 0, 0, 20, 20);
        canvas_.append(new FigureViewer(rect, new sgraphics.Point(20, 20)));

        style = new FigureStyle();
        style.foreground = Color.red;
        style.brushSize = 1;
        Glyph cir = FigureKit.circle(FigureMode.Stroke, style, 0, 0, 60);
        canvas_.append(new FigureViewer(cir, new sgraphics.Point(40, 40)));

        Sgraphics s = new Sgraphics();
        Toolkit kit = Toolkit.getDefaultToolkit();
        Image image = applet.getImage(applet.getCodeBase(), "sgraphics/example/camera.gif");
        Figure figimage = FigureKit.image(image, s.convertHorizontal(72), s.convertVertical(72));
        canvas_.append(new FigureViewer(figimage, new sgraphics.Point(90, 90)));

        image = applet.getImage(applet.getCodeBase(), "sgraphics/example/gopher.gif");
        figimage = FigureKit.image(image);
        canvas_.append(new FigureViewer(figimage, new sgraphics.Point(150, 10)));

        Glyph hbox = LayoutKit.hbox();
        hbox.append(viewport_);
        hbox.append(LayoutKit.hfixed(vbar_, 15));
        Glyph vbox = LayoutKit.vbox();
        vbox.append(hbox);
        Glyph hbox2 = LayoutKit.hbox();
        hbox2.append(LayoutKit.vfixed(hbar_, 15));
        hbox2.append(LayoutKit.hspace(15));
        vbox.append(hbox2);

        adapter_ = new SgraphicsAdapter(vbox);

        GridBagLayout layout = new GridBagLayout();
        setLayout(layout);

        GridBagConstraints constraints = new GridBagConstraints();
        constraints.gridx = 0;
        constraints.gridy = 0;
        constraints.gridwidth = 1;
        constraints.gridheight = 1;
        constraints.weightx = 1;
        constraints.weighty = 1;
        constraints.fill = GridBagConstraints.BOTH;
        layout.setConstraints(adapter_, constraints);
        add(adapter_);

		Panel p = new Panel();
		p.setLayout(new FlowLayout(FlowLayout.CENTER, 20, 10));
		p.add(zoomIn_);
		p.add(zoomOut_);
		p.add(quit_);

		constraints.gridx = 0;
		constraints.gridy = 1;
		constraints.weightx = 0;
		constraints.weighty = 0;
		constraints.gridwidth = 1;
		constraints.fill = GridBagConstraints.HORIZONTAL;
		layout.setConstraints(p, constraints);
		add(p);

        pack();
    }

    public boolean handleEvent (Event event) {
        if (event.target == zoomIn_ &&
                event.id == Event.ACTION_EVENT) {
            if (!zoomed_) {
                canvas_.setScale(2.0F);
                xAdjustment_.begin();
                xAdjustment_.scaleTo(2.0F);
                xAdjustment_.commit();
                yAdjustment_.begin();
                yAdjustment_.scaleTo(2.0F);
                yAdjustment_.commit();
                zoomed_ = true;
            }
        }
        else if (event.target == zoomOut_ &&
                event.id == Event.ACTION_EVENT) {
            if (zoomed_) {
                canvas_.setScale(1.0F);
                xAdjustment_.begin();
                xAdjustment_.scaleTo(1.0F);
                xAdjustment_.commit();
                yAdjustment_.begin();
                yAdjustment_.scaleTo(1.0F);
                yAdjustment_.commit();
                zoomed_ = false;
            }
        }
        else if (event.target == quit_ &&
            event.id == Event.ACTION_EVENT) {
            dispose();
            System.exit(0);
        }
        return super.handleEvent(event);
    }

    public void update (Graphics g) {
        paint(g);
    }
}
