package sgraphics.figure;

// Copyright (c) 1996    Michael A. Jones
// Copyright (c) 1997    Bill Petheram

import sgraphics.*;
import java.awt.*;
import java.awt.image.*;

class FigImage extends Figure implements ImageObserver {
    private Image image_ = null;
    private Allocation allocation_ = null;
    private float width_ = 0;
    private float height_ = 0;
    private Sgraphics s_ = new Sgraphics();

    public FigImage(Image image) {
        image_ = image;
        width_ = s_.convertHorizontal(image_.getWidth(this));
        height_ = s_.convertVertical(image_.getHeight(this));
    }

    public FigImage(Image image, float width, float height) {
        image_ = image;
        width_ = width;
        height_ = height;
    }

    public Requirements requirements () {

        Requirements r = new Requirements();
        r.x.defined = true;
        r.x.natural = width_;
        r.x.maximum = r.x.minimum = r.x.natural;
        r.x.align = 0;

        r.y.defined = true;
        r.y.natural = height_;
        r.y.maximum = r.y.minimum = r.y.natural;
        r.y.align = 0;
        return r;
    }

    public void allocate (Allocation allocation) {
        // If the allocation does not exist then set it.
        allocation_ = allocation;
    }

    public void draw (Painter painter) {
        if (allocation_ != null && image_ != null) {
            // Get info on where to draw.
            BoundingSpan xSpan = allocation_.allocation.span(Area.xAxis);
            BoundingSpan ySpan = allocation_.allocation.span(Area.yAxis);

            painter.drawImage(image_, xSpan.begin, ySpan.begin, getSgraphicsAdapter());
        }
    }

	public void pick (Picker pick) {
		if (allocation_ == null)
			return;

		BoundingSpan xSpan = allocation_.allocation.span(Area.xAxis);
		BoundingSpan ySpan = allocation_.allocation.span(Area.yAxis);

        float x1 = xSpan.begin;
        float y1 = ySpan.begin;
        float x2 = xSpan.end;
        float y2 = ySpan.end;

		if (pick.hitType == Picker.POINT) {
			float x = pick.x;
			float y = pick.y;

			if (x >= x1 && x <= x2 && y >= y1 && y <= y2) {
				pick.hit(this);
				}
			}
		else if (pick.hitType == Picker.AREA) {
			// Check all four corners to see if any corner is in my area.
			// Top left.
			if (pick.x >= x1 && pick.x <= x2 && pick.y >= y1 && pick.y <= y2) {
				pick.hit(this);
				return;
				}
			// Top right.
			if (pick.x + pick.width - 1 >= x1 && pick.x + pick.width - 1 <= x2 && pick.y >= y1 && pick.y <= y2) {
				pick.hit(this);
				return;
				}
			// Bottom left.
			if (pick.x >= x1 && pick.x <= x2 && pick.y + pick.height - 1 >= y1 && pick.y + pick.height - 1 <= y2) {
				pick.hit(this);
				return;
				}
			// Bottom right.
			if (pick.x + pick.width - 1 >= x1 && pick.x + pick.width - 1 <= x2 && pick.y + pick.height - 1 >= y1 && pick.y + pick.height - 1 <= y2) {
				pick.hit(this);
				return;
				}
			}
		}

	public void needRedraw () {
	    if (allocation_ != null)
	        needRedraw(allocation_.allocation);
	    else
	        super.needRedraw();
		}

    public boolean imageUpdate (Image image, int infoFlag, int x, int y, int width, int height) {
        boolean w = false;
        boolean h = false;
        if ((infoFlag & ImageObserver.WIDTH) != 0) {
            width_ = s_.convertHorizontal(width);
            w = true;
        }
        if ((infoFlag & ImageObserver.HEIGHT) != 0) {
            height_ = s_.convertVertical(height);
            h = true;
        }
        if (w && h) {
            needResize();
            return true;
        }
        return false;
    }
}


