package sgraphics.figure;

// Copyright (c) 1996    Michael A. Jones

import sgraphics.*;
import sgraphics.util.*;
import sgraphics.layout.Glue;

import java.awt.Graphics;
import java.awt.Color;
import java.awt.Toolkit;
import java.awt.FontMetrics;
import java.lang.*;

/**
 * A vertical bar. Stretches vertically. Used as an edit cursor. Relies on
 * a parent in the tree becomming null to know when to stop its thread.
 * Emptying a vbox or hbox will do this.
 */
class FigInsertBar extends Figure implements Runnable {
	private Allocation allocation_ = null;
    private Sgraphics s_ = new Sgraphics();
    private float align_;

	private boolean running_ = false;

	public void run () {
	    running_ = true;
	    while(running_) {
	        SgraphicsAdapter adapter = getSgraphicsAdapter();
	        if (adapter != null) {
	            draw(adapter.getPainter());
	        } else {
	            Thread t = Thread.currentThread();
	            t.stop();
	        }
	        try {
	            Thread.currentThread().sleep(500);
	        } catch (InterruptedException e) {
	        }
	        FigureStyle style = getStyle();
	        Color c = style.foreground;
	        style.foreground = style.background;
	        style.background = c;
			setStyle(style);
	    }
	}

	// Cache the metrics to speed up.
	public void setStyle (FigureStyle style) {
		if (style.font != null) {
			Toolkit kit = Toolkit.getDefaultToolkit();
			FontMetrics metrics = kit.getFontMetrics(style.font);
			float width = s_.convertHorizontal(metrics.stringWidth("ABCDEFGHIJKLMNOPQRSTUVWXYZ"));
			float height = s_.convertVertical(metrics.getHeight());
			align_ = s_.convertVertical(metrics.getAscent()) / height;

			}
		if (style.brushSize < 1)
			style.brushSize = 1;
		super.setStyle(style);
		}

	public Requirements requirements () {

		Requirements r = new Requirements();
		r.x.defined = true;
		r.x.natural = 0F;
		r.x.maximum = r.x.minimum = r.x.natural;
		r.x.align = 0;

		r.y.defined = true;
		r.y.natural = 0F;
		r.y.minimum = 0F;
		r.y.maximum = Glue.Fil;
		r.y.align = align_;

		return r;
		}

	public synchronized void allocate (Allocation allocation) {
		allocation_ = allocation;
		}

	public synchronized void draw (Painter painter) {
		if (allocation_ != null) {

		    if (!running_) {
		        Thread thread = new Thread(this);
		        thread.start();
		    }

    		BoundingSpan xSpan = allocation_.allocation.span(Area.xAxis);
    		BoundingSpan ySpan = allocation_.allocation.span(Area.yAxis);

			FigureStyle style = getStyle();
			if (style.foreground != null)
				painter.setColor(style.foreground);

			GraphicsUtil.drawLine(painter, xSpan.begin, ySpan.begin, xSpan.begin, ySpan.end, style.brushSize);
			}
		}

	public void needRedraw () {
	    if (allocation_ != null)
	        needRedraw(allocation_.allocation);
	    else
	        super.needRedraw();
    }
}
