package sgraphics.figure;

// Copyright (c) 1987-91 Stanford University
// Copyright (c) 1991-95 Silicon Graphics, Inc.
// Copyright (c) 1993-95 2001 S.A.
// Copyright (c) 1993-96 Fujitsu, Ltd.
// Copyright (c) 1994-96 Firefly Design
// Copyright (c) 1995-96 Vitria, Inc.
// Copyright (c) 1996    Michael A. Jones

import sgraphics.*;
import sgraphics.util.*;

import java.awt.Graphics;
import java.awt.Color;
import java.lang.Math;

/**
 * A line.
 * <p>
 * The Line does not stretch and does not pick.
 */
class FigLine extends Figure {
	private Point p1_ = null;
	private Point p2_  = null;
	private Allocation allocation_ = null;

	public FigLine (Point p1, Point p2) {
		p1_ = p1;
		p2_ = p2;
		}

	/**
	 * Return requirements based on the points of a rectangle. Requirements
	 * are calculated by subtracting the x and y points. The requirement is
	 * given for the rectangle without considering where the rectange is in
	 * the coordinate space.
	 */
	public Requirements requirements () {

		FigureStyle style = getStyle();
		if (style.brushSize < 1)
			style.brushSize = 1;

		Requirements r = new Requirements();
		r.x.defined = true;
		r.x.natural = Math.abs(p2_.x - p1_.x) + 1;
		r.x.maximum = r.x.minimum = r.x.natural;
		r.x.align = 0;

		r.y.defined = true;
		r.y.natural = Math.abs(p2_.y - p1_.y) + 1;
		r.y.maximum = r.y.minimum = r.y.natural;
		r.y.align = 0;

		return r;
		}

	public void allocate (Allocation allocation) {
		// If the allocation does not exist then set it.
		// If there is a allocation, then merge in the new one.
		allocation_ = allocation;
		}

// Will need to add cliping, checking for allocation if too small, etc.
	public void draw (Painter painter) {
		// Dont draw if there is no allocation.
		if (allocation_ != null) {
			// Get info on where to draw.
			// @@ Should also set the clipping regions later.

    		BoundingSpan xSpan = allocation_.allocation.span(Area.xAxis);
    		BoundingSpan ySpan = allocation_.allocation.span(Area.yAxis);

            float x1;
            float y1;
            float x2;
            float y2;

			if (p2_.x > p1_.x) {
				x1 = xSpan.begin + p1_.x;
				x2 = x1 + xSpan.length - 1F;
			}
			else {
				x2 = xSpan.begin + p2_.x;
				x1 = x2 + xSpan.length - 1F;
			}
			if (p2_.y > p1_.y) {
				y1 = ySpan.begin + p1_.y;
				y2 = y1 + ySpan.length - 1F;
			}
			else {
				y2 = ySpan.begin + p2_.y;
				y1 = y2 + ySpan.length - 1F;
			}

			FigureStyle style = getStyle();
			if (style.foreground != null)
				painter.setColor(style.foreground);

			GraphicsUtil.drawLine(painter, x1, y1, x2, y2, style.brushSize);
			}
		}

	public void needRedraw () {
	    if (allocation_ != null)
	        needRedraw(allocation_.allocation);
	    else
	        super.needRedraw();
	}
}
