package sgraphics.layout;

// Copyright (c) 1987-91 Stanford University
// Copyright (c) 1991-95 Silicon Graphics, Inc.
// Copyright (c) 1993-95 2001 S.A.
// Copyright (c) 1993-96 Fujitsu, Ltd.
// Copyright (c) 1994-96 Firefly Design
// Copyright (c) 1995-96 Vitria, Inc.
// Copyright (c) 1996    Michael A. Jones

import sgraphics.*;

/**
 * The Box class is used to contain glyphs and use a LayoutManager to
 * tile them.<p>
 * Warning: Requirements are cached and only calls to append(), prepend(), replace(), or empty()
 * or needResize() will clear the cache. Therefore, if an object changes size it
 * must call needResize().
 */
class Box extends PolyGlyph {
	private LayoutManager layoutManager_;
	private Requirements requirements_ = null;

	public Box (LayoutManager manager) {
		layoutManager_ = manager;
		}

	public Requirements requirements () {
	    Requirements r;

        if (Sgraphics.cacheRequirements) {
    		if (requirements_ == null) {
    			requirements_ = new Requirements();
    			layoutManager_.requirements(children_, requirements_);
    			}
    		r = new Requirements(requirements_);
    	}
    	else {
		r = new Requirements();
	    layoutManager_.requirements(children_, r);
    	}
		return r;
		}

	public void allocate (Allocation allocation) {
		layoutManager_.allocate(children_, allocation);
		}

	public void append (Glyph glyph) {
		requirements_ = null;
		super.append(glyph);
		}

	public void prepend (Glyph glyph) {
		requirements_ = null;
		super.prepend(glyph);
		}

	public void replace (int position, Glyph glyph) {
		requirements_ = null;
		super.replace(position, glyph);
		}

	public void swap (int position1, int position2) {
		requirements_ = null;
		super.swap(position1, position2);
		}

	public void empty () {
		requirements_ = null;
		super.empty();
		}

	public void needResize () {
		requirements_ = null;
		super.needResize();
		}
}
