package sgraphics.layout;

// Copyright (c) 1987-91 Stanford University
// Copyright (c) 1991-95 Silicon Graphics, Inc.
// Copyright (c) 1993-95 2001 S.A.
// Copyright (c) 1993-96 Fujitsu, Ltd.
// Copyright (c) 1994-96 Firefly Design
// Copyright (c) 1995-96 Vitria, Inc.
// Copyright (c) 1996    Michael A. Jones

import sgraphics.*;

/**
 * Centers a single glyph. Assumes that the list[] parameter in
 * requirements() and allocate() has only one glyph.
 */
class CenterLayout extends LayoutManager implements Axis {
	private int axis_;
	private float align_;

	/**
	 *
	 * Layout by setting the alignment along an axis.
	 *
	 * @param axis the axis to center along.
	 * @param align the alignment.
	 */
	public CenterLayout (int axis, float align) {
		axis_ = axis;
		align_ = align;
		}

	public void requirements (Glyph list[], Requirements requirements) {
		Requirement r = GlyphImpl.requirement(requirements, axis_);
		r.align = align_;
		}

	public void allocate (Glyph list[], Allocation allocation) {
		Allocation allocations[] = calculateAllocations(list, allocation);
		list[0].allocate(allocations[0]);
		}

	public Allocation[] allocations (Glyph list[], Allocation allocation) {
		return calculateAllocations(list, allocation);
		}

	private Allocation[] calculateAllocations (Glyph list[], Allocation allocation) {
		Area area = allocation.allocation;

		BoundingSpan span = area.span(axis_);
		Requirement r = GlyphImpl.requirement(list[0].requirements(), axis_);
		Allocation allocations[] = new Allocation[1];
		allocations[0] = new Allocation();
		if (r.defined) {
			// This was from the C++ version and was removed. The problem is that
			// the requirements may have been modifed by flexible or natural
			// by a glyph that is closer to the root of the glyph tree and
			// then this changes the length when it should not. For example:
			// if a glyph has min, max, and natural equal, and then natural
			// changes, this will stretch the glyph back out to the orignal
			// value becase min and max never changed.
			//float length = Math.min(r.maximum, Math.max(r.minimum, span.length));

			float length = span.length;

			float x1 = 0;
			float x2 = 0;
			float xAlign = 0;
			float y1 = 0;
			float y2 = 0;
			float yAlign = 0;

			switch (axis_) {
				case xAxis :
					//    Shift the origin to center the glyph
					x1 = (span.origin + (r.align - span.align) * (length - 1)) -
					// Adjust for begin point.
					(length - 1) * r.align;
					x2 = x1 + length - 1;
					xAlign = r.align;

					BoundingSpan ySpan = area.span(yAxis);
					y1 = ySpan.begin;
					y2 = ySpan.end;
					yAlign = ySpan.align;

        			allocations[0].allocation = new Area(x1, y1, xAlign, true, x2, y2, yAlign, false);
        			allocations[0].clipping = new Area(x1, y1, xAlign, true, x2, y2, yAlign, false);
					break;
				case yAxis :
					//    Shift the origin to center the glyph
					y1 = (span.origin + (r.align - span.align) * (length - 1)) -
					// Adjust for begin point.
					(length - 1) * r.align;
					y2 = y1 + length - 1;
					yAlign = r.align;

					BoundingSpan xSpan = area.span(xAxis);
					x1 = xSpan.begin;
					x2 = xSpan.end;
					xAlign = xSpan.align;

        			allocations[0].allocation = new Area(x1, y1, xAlign, false, x2, y2, yAlign, true);
        			allocations[0].clipping = new Area(x1, y1, xAlign, false, x2, y2, yAlign, true);
					break;
				}
			}
		return allocations;
		}

}
