package sgraphics.layout;

// Copyright (c) 1987-91 Stanford University
// Copyright (c) 1991-95 Silicon Graphics, Inc.
// Copyright (c) 1993-95 2001 S.A.
// Copyright (c) 1993-96 Fujitsu, Ltd.
// Copyright (c) 1994-96 Firefly Design
// Copyright (c) 1995-96 Vitria, Inc.
// Copyright (c) 1996    Michael A. Jones

import sgraphics.*;

/**
 * Centers a single glyph. Assumes that the list[] parameter in
 * requirements() and allocate() has only one glyph.
 */
class FixedLayout extends LayoutManager implements Axis {
	private int axis_;
	private float size_;

	/**
	 *
	 * Layout by setting fixing the size along an axis;
	 *
	 * @param axis the axis to fix.
	 * @param size the size along the axis.
	 */
	public FixedLayout (int axis, float size) {
		axis_ = axis;
		size_ = size;
		}

	public void requirements (Glyph list[], Requirements requirements) {
		Requirement r = GlyphImpl.requirement(requirements, axis_);
		r.natural = size_;
		r.maximum = size_;
		r.minimum = size_;
		if (!r.defined) {
			r.defined = true;
			r.align = 0F;
			}
		}

	public void allocate (Glyph list[], Allocation allocation) {
		Allocation allocations[] = calculateAllocations(list, allocation);
		list[0].allocate(allocations[0]);
		}

	public Allocation[] allocations (Glyph list[], Allocation allocation) {
		return calculateAllocations(list, allocation);
		}

	private Allocation[] calculateAllocations (Glyph list[], Allocation allocation) {
		Allocation a[] = new Allocation[1];
		a[0] = allocation;
		return a;
		}

}
