package sgraphics.layout;

import sgraphics.*;

// Copyright (c) 1987-91 Stanford University
// Copyright (c) 1991-94 Silicon Graphics, Inc.
// Copyright (c) 1993-94 Fujitsu, Ltd.

/**
 * An adjustment constraint controls the allowable scrolling region
 * for an adjustment.
 */
class FullyVisibleConstraint implements AdjustmentConstraint {
    private float usable_;
    private float align_;

    public FullyVisibleConstraint (float usable, float align) {
        usable_ = usable;
        align_ = align;
    }

	/**
	 * Constrain the value to be within the allowable scrolling region.
     */
    public float constrain (float lower, float length, float currentLength, float value) {

        float lowerLimit;
        float upperLimit;
        float space = currentLength - length;
        if (space > 0) {
	        float usableSpace = space * usable_;
	        float marginSpace = space - usableSpace;
	        upperLimit = lower - marginSpace * align_;
	        lowerLimit = upperLimit - usableSpace;
        } else {
	        lowerLimit = lower;
	        upperLimit = lowerLimit - space;
        }

        if (value < lowerLimit) {
	        value = lowerLimit;
        } else if (value > upperLimit) {
	        value = upperLimit;
        }

        return value;

    }

	/**
	 * Return the scroll position to move the view to the beginning of
	 * the data.
     */
    public float scrollBegin(float lower, float length, float currentLength) {
        return 0.0F;
    }

	/**
	 * Return the scroll position to move the view to the end of
	 * the data.
     */
    public float scrollEnd(float lower, float length, float currentLength) {
        return 0.0F;
    }

}
