package sgraphics.layout;

// Copyright (c) 1987-91 Stanford University
// Copyright (c) 1991-95 Silicon Graphics, Inc.
// Copyright (c) 1993-95 2001 S.A.
// Copyright (c) 1993-96 Fujitsu, Ltd.
// Copyright (c) 1994-96 Firefly Design
// Copyright (c) 1995-96 Vitria, Inc.
// Copyright (c) 1996    Michael A. Jones

import sgraphics.*;

/**
 * Glue is used to create stretchable and shrinkable white space.
 */
public class Glue extends GlyphImpl implements Axis {
	private Requirement requirement_ = new Requirement();
	private int axis_;

	/**
	 * Infinite stretch value.
	 */
	public static final float Fil = 1.0E+12F;

	/**
	 * Construct Glue.
	 *
	 * @param axis xAxis or yAxis.
	 * @param natural the unstretched or unshrunk size.
	 * @param stretch how far the glue can stretch (>= 0).
	 * @param shrink how far the glue can shrink (>= 0).
	 * @param align the alignment (>= 0 && <= 1).
	 */
	public Glue (int axis, float natural, float stretch, float shrink, float align) {
		requirement_.defined = true;
		requirement_.natural = natural;
		requirement_.maximum = natural + stretch;
		requirement_.minimum = natural - shrink;
		requirement_.align = align;
		axis_ = axis;
		}

	public Glue (Requirement requirement) {
		requirement_ = requirement;
		}

	public Requirements requirements () {
		Requirements r = new Requirements();
		switch (axis_) {
			case xAxis :
				r.x = requirement_;
				break;
			case yAxis :
				r.y = requirement_;
				break;
			}
		return r;
		}
}
