package sgraphics.layout;

// Copyright (c) 1987-91 Stanford University
// Copyright (c) 1991-95 Silicon Graphics, Inc.
// Copyright (c) 1993-95 2001 S.A.
// Copyright (c) 1993-96 Fujitsu, Ltd.
// Copyright (c) 1994-96 Firefly Design
// Copyright (c) 1995-96 Vitria, Inc.
// Copyright (c) 1996    Michael A. Jones

import sgraphics.*;

/**
 * Add margin to a glyph.
 */
class MarginLayout extends LayoutManager implements Axis {
	private float lnatural_ = 0;
	private float rnatural_ = 0;
	private float bnatural_ = 0;
	private float tnatural_ = 0;
	private float lstretch_ = 0;
	private float rstretch_ = 0;
	private float bstretch_ = 0;
	private float tstretch_ = 0;
	private float lshrink_ = 0;
	private float rshrink_ = 0;
	private float bshrink_ = 0;
	private float tshrink_ = 0;

	public MarginLayout (float margin) {
		lnatural_ = margin;
		rnatural_ = margin;
		bnatural_ = margin;
		tnatural_ = margin;
		}

	public MarginLayout (float hmargin, float vmargin) {
		lnatural_ = hmargin;
		rnatural_ = hmargin;
		bnatural_ = vmargin;
		tnatural_ = vmargin;
		}

	public MarginLayout (float lmargin, float rmargin, float bmargin, float tmargin) {
		lnatural_ = lmargin;
		rnatural_ = rmargin;
		bnatural_ = bmargin;
		tnatural_ = tmargin;
		}

	public MarginLayout (
		float lmargin, float lstretch, float lshrink,
		float rmargin, float rstretch, float rshrink,
		float bmargin, float bstretch, float bshrink,
		float tmargin, float tstretch, float tshrink) {

		lnatural_ = lmargin;
		rnatural_ = rmargin;
		bnatural_ = bmargin;
		tnatural_ = tmargin;
		lstretch_ = lstretch;
		rstretch_ = rstretch;
		bstretch_ = bstretch;
		tstretch_ = tstretch;
		lshrink_ = lshrink;
		rshrink_ = rshrink;
		bshrink_ = bshrink;
		tshrink_ = tshrink;
		}

	public void requirements (Glyph list[], Requirements requirements) {
		Requirement rx = GlyphImpl.requirement(requirements, xAxis);
		if (!rx.defined) {
			rx.defined = true;
			rx.natural = 0F;
			rx.maximum = 0F;
			rx.minimum = 0F;
			}

		float dx = lnatural_ + rnatural_;
		rx.natural += dx;
		rx.maximum += dx + (lstretch_ + rstretch_);
		rx.minimum += dx - (lshrink_ + rshrink_);

		Requirement ry = GlyphImpl.requirement(requirements, yAxis);
		if (!ry.defined) {
			ry.defined = true;
			ry.natural = 0F;
			ry.maximum = 0F;
			ry.minimum = 0F;
			}

		float dy = bnatural_ + tnatural_;
		ry.natural += dy;
		ry.maximum += dy + (bstretch_ + tstretch_);
		ry.minimum += dy - (bshrink_ + tshrink_);
		}

	public void allocate (Glyph list[], Allocation allocation) {
		Allocation allocations[] = calculateAllocations(list, allocation);
		list[0].allocate(allocations[0]);
		}

	public Allocation[] allocations (Glyph list[], Allocation allocation) {
		return calculateAllocations(list, allocation);
		}

	private Allocation[] calculateAllocations (Glyph list[], Allocation allocation) {

		Area a  = allocation.allocation;
		BoundingSpan s = a.span(xAxis);

		Requirements requirements = list[0].requirements();
		requirements(list, requirements);

		Requirement r = GlyphImpl.requirement(requirements, xAxis);
		float lead = span(s.length, r, lnatural_, lstretch_, lshrink_);
		float trail = span(s.length, r, rnatural_, rstretch_, rshrink_);
		s.length -= (lead + trail);
		s.origin += ((1 - r.align) * lead - r.align * trail);

        // I am not sure why Fresco did this. I basically gives the whole
        // allocation, including the margin, to the child. If the child
        // can stretch it will use it and the margin will not show.
		float x1 = s.origin - (s.length - 1) * s.align;
		float x2 = x1 + s.length - 1;
		float xAlign = s.align;

		s = a.span(yAxis);

		r = GlyphImpl.requirement(requirements, yAxis);
		lead = span(s.length, r, tnatural_, tstretch_, tshrink_);
		trail = span(s.length, r, bnatural_, bstretch_, bshrink_);
		s.length -= (lead + trail);
		s.origin += ((1 - r.align) * lead - r.align * trail);

		float y1 = s.origin - (s.length - 1) * s.align;
		float y2 = y1 + s.length - 1;
		float yAlign = s.align;

		Allocation alloc[] = new Allocation[1];
		alloc[0] = new Allocation();
		alloc[0].allocation = new Area(x1, y1, xAlign, x2, y2, yAlign);
		alloc[0].clipping = new Area(x1, y1, xAlign, x2, y2, yAlign);
		return alloc;
		}

	private float span (float span, Requirement total, float natural, float stretch, float shrink) {
		float extra = span - total.natural;
		float result = natural;
		float ss = 0F;
		float totalStretch = total.maximum - total.natural;
		float totalShrink = total.natural - total.minimum;
		if (extra > 0 && totalStretch > 0) {
			ss = stretch / totalStretch;
			}
		else if (extra < 0 && totalShrink > 0) {
			ss = shrink / totalShrink;
			}
		return result + ss * extra;
		}

}
