package sgraphics.layout;

// Copyright (c) 1987-91 Stanford University
// Copyright (c) 1991-95 Silicon Graphics, Inc.
// Copyright (c) 1993-95 2001 S.A.
// Copyright (c) 1993-96 Fujitsu, Ltd.
// Copyright (c) 1994-96 Firefly Design
// Copyright (c) 1995-96 Vitria, Inc.
// Copyright (c) 1996    Michael A. Jones

import sgraphics.*;

class SuperposeLayout extends LayoutManager {
	private LayoutManager first_;
	private LayoutManager second_;

	public SuperposeLayout (LayoutManager first, LayoutManager second) {
		first_ = first;
		second_ = second;
	}

	public void requirements (Glyph list[], Requirements requirements) {
		if (first_ != null) {
			first_.requirements(list, requirements);
		}
		if (second_ != null) {
			second_.requirements(list, requirements);
		}
	}

	public void allocate (Glyph list[], Allocation allocation) {
		Allocation firstAllocations[] = null;
		Allocation secondAllocations[] = null;
		if (first_ != null) {
			if (second_ != null)
				firstAllocations = first_.allocations(list, allocation);
			else {
				first_.allocate(list, allocation);
				return;
			}
		}
		if (second_ != null) {
			if (first_ != null)
				secondAllocations = second_.allocations (list, allocation);
			else {
				second_.allocate(list, allocation);
				return;
			}
		}

		// We should only get here if first_ and second_ are not null;
		int length = firstAllocations.length;
		for (int cnt = 0; cnt < length; cnt++) {
			// Try to use one allocation for x and the other for y, else
			// do a union.

			// Get the areas.
			Area a1 = firstAllocations[cnt].allocation;
			Area a2 = secondAllocations[cnt].allocation;

			// Get the spans.
			BoundingSpan a1X = a1.span(Area.xAxis);
			BoundingSpan a1Y = a1.span(Area.yAxis);
			BoundingSpan a2X = a2.span(Area.xAxis);
			BoundingSpan a2Y = a2.span(Area.yAxis);
			boolean a1IsXOnly = false;
			boolean a1IsYOnly = false;
			boolean a2IsXOnly = false;
			boolean a2IsYOnly = false;

			// Find out which areas are x or y only.
			if (!a1.yDefined() && a1.xDefined())
				a1IsXOnly = true;
			if (!a1.xDefined() && a1.yDefined())
				a1IsYOnly = true;
			if (!a2.yDefined() && a2.xDefined())
				a2IsXOnly = true;
			if (!a2.xDefined() && a2.yDefined())
				a2IsYOnly = true;

			// Either combine the areas or mergeUnion.

			Area combinedArea;
			if (a1IsXOnly && a2IsYOnly) {
				combinedArea = new Area(a1X.begin, a2Y.begin, a1X.align, a1X.end, a2Y.end, a2Y.align);
			}
			else if (a1IsYOnly && a2IsXOnly) {
				combinedArea = new Area(a2X.begin, a1Y.begin, a2X.align, a2X.end, a1Y.end, a1Y.align);
			}
			else {
				a1.mergeUnion(a2);
				combinedArea = a1;
			}

			// Call allocate on the glyph.
			Allocation a = new Allocation();
			a.allocation = combinedArea;
			a.clipping = combinedArea;
			list[cnt].allocate(a);
		}
	}

}
