package sgraphics.layout;

// Copyright (c) 1987-91 Stanford University
// Copyright (c) 1991-95 Silicon Graphics, Inc.
// Copyright (c) 1993-95 2001 S.A.
// Copyright (c) 1993-96 Fujitsu, Ltd.
// Copyright (c) 1994-96 Firefly Design
// Copyright (c) 1995-96 Vitria, Inc.
// Copyright (c) 1996    Michael A. Jones

import sgraphics.*;

/**
 * Allows a glyph to stretch and shrink, even if the glyph is not
 * flexible. If the glyph is flexible, the stretch and shrink are changed.
 */
class VariableLayout extends LayoutManager implements Axis {
	private int axis_;
	private float stretch_;
	private float shrink_;

	/**
	 *
	 * Layout by setting the stretch and shrink;
	 *
	 * @param axis the axis to fix.
	 * @param size the size along the axis.
	 */
	public VariableLayout (int axis, float stretch, float shrink) {
		axis_ = axis;
		stretch_ = stretch;
		shrink_ = shrink;
		}

	public void requirements (Glyph list[], Requirements requirements) {
		Requirement r = GlyphImpl.requirement(requirements, axis_);
		r.maximum = r.natural + stretch_;
		r.minimum = r.natural - shrink_;
		}

	public void allocate (Glyph list[], Allocation allocation) {
		Allocation allocations[] = calculateAllocations(list, allocation);
		list[0].allocate(allocations[0]);
		}

	public Allocation[] allocations (Glyph list[], Allocation allocation) {
		return calculateAllocations(list, allocation);
		}

	private Allocation[] calculateAllocations (Glyph list[], Allocation allocation) {
		Allocation a[] = new Allocation[1];
		a[0] = allocation;
		return a;
		}

}
