package sgraphics.test;

// Copyright (c) 1996    Michael A. Jones

import java.awt.Frame;
import java.awt.BorderLayout;
import java.awt.Label;
import java.awt.Color;
import java.awt.Font;

import sgraphics.Glyph;
import sgraphics.Point;
import sgraphics.SgraphicsAdapter;
import sgraphics.figure.Figure;
import sgraphics.figure.FigureKit;
import sgraphics.figure.FigureMode;
import sgraphics.figure.FigureStyle;
// Changed these so Cafe with JDK 1.1 would compile.
//import sgraphics.layout.Box;
//import sgraphics.layout.SuperposeLayout;
//import sgraphics.layout.TileLayout;
//import sgraphics.layout.AlignLayout;
//import sgraphics.layout.LayoutKit;
import sgraphics.layout.*;
import sgraphics.DebugGlyph;
import sgraphics.test.ColorChanger;
import sgraphics.widget.*;
import sgraphics.wrapper.*;

public class TestRectangle {
	public static void main (String args[]) {
		System.out.println ("Start test...");

		Frame f = new Frame();
		f.resize(900, 550);
		f.setLayout(new BorderLayout());

		// The blue square
		FigureStyle style = new FigureStyle();
		style.foreground = Color.blue;
		style.brushSize = 6;
		Glyph rect1 = new ColorChanger(FigureKit.rectangle(FigureMode.Stroke, style, 0, 0, 20, 20));

		// The red solid square
		style = new FigureStyle();
		style.foreground = Color.red;
		Figure rect2 = FigureKit.rectangle(FigureMode.Fill, style, 0, 0, 40, 35);

		// A set of squares in a hbox
		Glyph vb = LayoutKit.vbox();
		vb.append(LayoutKit.vfil());
		Glyph hb = LayoutKit.hbox();
		hb.append(LayoutKit.hfil());
		style = new FigureStyle();
		style.foreground = Color.red;
		Glyph rect3 = LayoutKit.align(new ColorChanger(FigureKit.rectangle(FigureMode.Stroke, style, 0, 0, 40, 40)), 0F, 0.5F);
		hb.append(LayoutKit.hnatural(rect3, 30F));

		style = new FigureStyle();
		style.foreground = Color.blue;
		Glyph rect4 = LayoutKit.align(FigureKit.rectangle(FigureMode.Stroke, style, 0, 0, 20, 20), 0F, 0.5F);
		hb.append(LayoutKit.vflexible(rect4, 10F, 0F));

		style = new FigureStyle();
		style.foreground = Color.red;
		style.brushSize = 1;
		Glyph circle1 = LayoutKit.align(new ColorChanger(FigureKit.oval(FigureMode.Fill, style, 0, 0, 40, 60)), 0F, 0.5F);
		hb.append(circle1);

		Glyph button = new ButtonTester (LayoutKit.align(new ButtonGlyph("Sample Text!"), 0F, 0.5F));
		hb.append(button);

        ListGlyph list;
		Glyph l = LayoutKit.align(list = new ListGlyph(), 0F, 0.5F);
		hb.append(l);
		list.addItem("Item 1");
		list.addItem("Item 2");
		list.addItem("Item 3");
		list.addItem("Item 4");

		Glyph checkbox = LayoutKit.vfixed(new CheckboxGlyph("check me"), 10.0F);
		style = new FigureStyle();
		style.foreground = Color.black;
		style.background = Color.white;
		style.font = new Font("Helvetica", Font.PLAIN, 16);
		Glyph labelBox = new LabeledOutline(checkbox, FigureKit.label(style, "Label"), Color.blue, Color.green);
		hb.append(labelBox);

        ChoiceGlyph choice;
		Glyph c = LayoutKit.align(choice = new ChoiceGlyph(), 0F, 0.5F);
		hb.append(c);
		choice.addItem("Item 1");
		choice.addItem("Item 2");
		choice.addItem("Item 3");
		choice.addItem("Item 4");

		TextAreaGlyph ta = new TextAreaGlyph ("Text goes here\nand here", 8, 8);
		ta.setEditable(true);
		hb.append(ta);

		ScrollbarGlyph scr = new ScrollbarGlyph(ScrollbarGlyph.VERTICAL);
		hb.append(scr);

		TextFieldGlyph tf = new TextFieldGlyph ("field", 6);
		hb.append(tf);

		hb.append(LayoutKit.hfil());
		vb.append(LayoutKit.valign(hb, 0F));

		Glyph textBox = LayoutKit.hbox();
		style = new FigureStyle();
		style.foreground = Color.yellow;
		style.background = Color.red;
		style.font = new Font("Courier", Font.PLAIN, 16);
		Glyph text = FigureKit.label(style, "LHXX0101");
		textBox.append(new ColorChanger(text));
		style = new FigureStyle();
		style.foreground = Color.red;
		style.background = Color.yellow;
		style.font = new Font("Helvetica", Font.PLAIN, 8);
		text = FigureKit.label(style, "Loop 10: ");
		textBox.prepend(text);
		vb.append(LayoutKit.valign(textBox, 0));

        vb.append(LayoutKit.vspace(20));

		Glyph over = LayoutKit.overlay();
		style = new FigureStyle();
		style.foreground = Color.black;
		Glyph rect5 = LayoutKit.align(FigureKit.rectangle(FigureMode.Stroke, style, 0, 0, 100, 50), 0.5F, 0.5F);;
		over.append(LayoutKit.flexible(rect5, 10F, 0F));
		style = new FigureStyle();
		style.foreground = Color.green;
		style.brushSize = 3;
		Glyph rect6 = LayoutKit.align(FigureKit.rectangle(FigureMode.Stroke, style, 0, 0, 80, 30), 0.5F, 0.5F);
		over.append(rect6);
		vb.append(LayoutKit.align(over, 0, 0));

		style = new FigureStyle();
		style.foreground = Color.red;
		style.brushSize = 3;
		Glyph line = FigureKit.line (style, 10, 0, 150, 0);
		vb.append(line);

		style = new FigureStyle();
		style.foreground = Color.black;
		style.brushSize = 1;
		Glyph rect7 = FigureKit.rectangle(FigureMode.Fill, style, 0, 0, 50, 50);
		style = new FigureStyle();
		style.foreground = Color.yellow;
		style.brushSize = 1;
		Glyph rect8 = FigureKit.rectangle(FigureMode.Fill, style, 0, 0, 25, 25);
		Glyph between = LayoutKit.front(rect7, rect8);
		vb.append(between);

		vb.append(LayoutKit.vfil());

		SgraphicsAdapter a1 = new SgraphicsAdapter(rect1);
		SgraphicsAdapter a2 = new SgraphicsAdapter(LayoutKit.margin (rect2, 20));
		SgraphicsAdapter a3 = new SgraphicsAdapter(vb);
		f.add("North", new Label("me"));
		f.add("West", new Label("me"));
		f.add("South", a1);
		f.add("East", a2);
		f.add("Center", a3);
		f.show();

		System.out.println ("Test complete");
		}
}
