package sgraphics.tutorial;

// Copyright (c) 1996    Michael A. Jones

import java.awt.Color;
import sgraphics.*;
import sgraphics.figure.*;
import sgraphics.layout.*;
import sgraphics.wrapper.*;


public class GridPackage extends MonoGlyph {
    private float graphicalSize_;
    private StretchableActivePin selectedPin_ = null;

	public GridPackage(int gridSize, int openSize, float graphicalSize, ViewerCallback pinCallback) {
	    graphicalSize_ = graphicalSize;

		FigureStyle style = new FigureStyle();
		style.foreground = Color.yellow;
		style.brushSize = 1;

        Glyph verticalBox = LayoutKit.vbox();

        float itemSize = graphicalSize / (float) gridSize;

        for (int row = 0; row < gridSize; row++) {
		    Glyph horizontalRow = LayoutKit.hbox();
		    for (int col = 0; col < gridSize; col++)
		        if (row >= (gridSize - openSize) / 2 &&
		            row < (gridSize - openSize) / 2 + openSize &&
		            col >= (gridSize - openSize) / 2 &&
		            col < (gridSize - openSize) / 2 + openSize) {
		            horizontalRow.append(LayoutKit.hglue(itemSize, itemSize, itemSize));
		        }
		        else {
		            String pinName = "Pin " + String.valueOf(row) + "X" + String.valueOf(col);
		            horizontalRow.append(
	                    new StretchableActivePin(pinName, row, col, itemSize, itemSize, itemSize, pinCallback));
		        }
		    verticalBox.append(horizontalRow);
		}

        ResizableFrame frame = new ResizableFrame (
            new Background(verticalBox, Color.gray, true, true),
            Color.black,
            Color.white);
		frame.setConstraints(160F, 300F, 160F, 300F);
		frame.lockSides();
        setBody(frame);
	}

}
