package sgraphics.tutorial;

// Copyright (c) 1996    Michael A. Jones

import java.awt.*;
import sgraphics.*;
import sgraphics.figure.*;
import sgraphics.layout.*;
import sgraphics.widget.*;


public class StretchableActivePin extends ViewerImpl {
    private String name_;
    private int row_;
    private int col_;
    private float natural_;
    private float stretch_;
    private float shrink_;
    private Allocation allocation_;
    private Glyph ring_;
    private boolean editing_ = false;
    private TextFieldGlyph field_ = new TextFieldGlyph();
	private Sgraphics s_ = new Sgraphics();

    private float editHeight = 26;
    private float editWidth = 80;
	private int fontSize = s_.convertVertical(14F);

    public StretchableActivePin (String name, int row, int column, float natural, float stretch, float shrink, ViewerCallback callback) {
        super(null);
        name_ = name;
        row_ = row;
        col_ = column;
        natural_ = natural;
        stretch_ = stretch;
        shrink_ = shrink;

        FigureStyle style = new FigureStyle();
		style.foreground = Color.yellow;
		style.brushSize = 1;

    	ring_ = LayoutKit.marginFlexible(
    	    LayoutKit.flexible(
    	        FigureKit.circle(FigureMode.Fill, style, 0, 0, natural_ * 0.8F),
    	        (natural_ * 0.8F),
    	        (natural_ * 0.8F)),
    	    (natural_ * 0.2F)/2F,
    	    (stretch_ * 0.2F)/2F,
    	    (shrink_ * 0.2F)/2F);

        setBody(ring_);

        setCallback(callback);
        field_.setCallback(callback);

        field_.setFont(new Font("Courier", Font.PLAIN, fontSize));
    }

	public Requirements requirements () {
		Requirements r = new Requirements();
		r.x.defined = true;
		r.x.natural = natural_;
		r.x.maximum = natural_ + stretch_;
		r.x.minimum = natural_ - shrink_;
		r.x.align = 0;

		r.y.defined = true;
		r.y.natural = natural_;
		r.y.maximum = natural_ + stretch_;
		r.y.minimum = natural_ - shrink_;
		r.y.align = 0;
		return r;
		}

    public void allocate (Allocation allocation) {
        if (!editing_)
            super.allocate(allocation);
        else {
            // Change the allocation for the edit field.
            BoundingSpan xSpan = allocation.allocation.span(Axis.xAxis);
            BoundingSpan ySpan = allocation.allocation.span(Axis.yAxis);
            Allocation a = new Allocation();
            a.allocation = new Area(xSpan.begin, ySpan.begin + ySpan.length/2F - editHeight/2F, 0F, xSpan.begin + editWidth, ySpan.begin + ySpan.length/2F + editHeight/2F, 0F);
            a.clipping = allocation.clipping;
            super.allocate(a);
        }
	    allocation_ = allocation;
	}

	public void draw (Painter painter) {
	    super.draw(painter);

		if (allocation_ != null && !editing_) {
   			BoundingSpan xSpan = allocation_.allocation.span(Area.xAxis);
			BoundingSpan ySpan = allocation_.allocation.span(Area.yAxis);

			float width = xSpan.length * 0.25F;
			float height = ySpan.length * 0.25F;

			painter.setColor(Color.black);
			painter.fillOval(xSpan.begin + xSpan.length/2F - width/2F,
			    ySpan.begin + ySpan.length/2F - height/2F,
			    width,
			    height);
	    }
	}

    public String getName () {
        return name_;
    }

    public void beginEdit () {
        if (editing_)
            return;
        editing_ = true;
		field_.setText(name_);
		field_.select(0,0);
		setBody(field_);
		needResize();
    }

    public void endEdit () {
        if (!editing_)
            return;
        editing_ = false;
        name_ = field_.getText();
        setBody(ring_);
        needResize();
    }

    public boolean editing () {
        return editing_;
    }
}
