package sgraphics.tutorial;

// Copyright (c) 1996    Michael A. Jones
// Copyright (c) 1997    Bill Petheram

import java.applet.*;
import java.awt.*;
import sgraphics.*;
import sgraphics.figure.*;
import sgraphics.layout.*;
import sgraphics.wrapper.*;


public class TutorialExample7 extends Applet {
		private TextField pinNameField_ = new TextField(20);
		private StretchableActivePinCallback callback_ = new StretchableActivePinCallback(pinNameField_);

		private GridPackage part_;
		private Glyph hbox_;
		private Glyph vbox_;
		private Glyph columnBox_;
        private Glyph rowBox_;
        private float columnBoxHeight_;
        private SgraphicsAdapter adapter_;

        public static void main (String arg[]) {

        Applet applet = new TutorialExample7();
        Frame frame = new AppletFrame("Example 7", applet, 550, 600);
        frame.show();
    }

	public TutorialExample7() {
	    setLayout(new BorderLayout());
	    setBackground(Color.white);

		part_ = new GridPackage(8, 4, 256, callback_);

		columnBox_ = LayoutKit.hbox();
		FigureStyle style = new FigureStyle();
		style.foreground = Color.black;
		style.font = new Font("Courier", Font.PLAIN, 16);
	    for (int col = 0; col < 8; col++) {
		    columnBox_.append(LayoutKit.hfil());
	        columnBox_.append(LayoutKit.align(FigureKit.label(style, String.valueOf(col)), 0F, 0F));
		    columnBox_.append(LayoutKit.hfil());
	    }

	    rowBox_ = LayoutKit.vbox();
		Toolkit kit = Toolkit.getDefaultToolkit();
		FontMetrics metrics = kit.getFontMetrics(style.font);
		Sgraphics s = new Sgraphics();
		columnBoxHeight_ = s.convertVertical(metrics.getHeight());
		rowBox_.append(LayoutKit.vspace(columnBoxHeight_));
	    for (int row = 0; row < 8; row++) {
		    rowBox_.append(LayoutKit.vfil());
	        rowBox_.append(LayoutKit.align(FigureKit.label(style, String.valueOf((char) (row + 65))), 0F, 0F));
		    rowBox_.append(LayoutKit.vfil());
	    }

	    vbox_ = LayoutKit.vbox();
	    vbox_.append(LayoutKit.align(columnBox_, 0, 0));
	    vbox_.append(LayoutKit.fixed(part_, 256F, 256F));

	    hbox_ = LayoutKit.hbox();
	    hbox_.append(LayoutKit.vfixed(rowBox_, columnBoxHeight_ + 256F));
	    hbox_.append(LayoutKit.hspace(4F));
	    hbox_.append(vbox_);

		Glyph device = LayoutKit.margin(hbox_, (450F - 256F - 40F) / 2F);
		adapter_ = new SgraphicsAdapter(device);

		add("Center", adapter_);

		pinNameField_.setEditable(false);
		add("South", pinNameField_);
	}

	public boolean handleEvent (Event event) {
	    if (event instanceof FrameResizeEvent) {
	        FrameResizeEvent resizeEvent = (FrameResizeEvent) event;
	        float newSize = Math.min(resizeEvent.frameWidth, resizeEvent.frameHeight);

	        vbox_.empty();
	        vbox_.append(LayoutKit.align(columnBox_, 0, 0));
	        vbox_.append(LayoutKit.fixed(part_, newSize, newSize));

	        hbox_.empty();
	        hbox_.append(LayoutKit.vfixed(rowBox_, columnBoxHeight_ + newSize));
	        hbox_.append(LayoutKit.hspace(4F));
	        hbox_.append(vbox_);

		    Glyph device = LayoutKit.margin(hbox_, (450F - newSize - 40F) / 2F);
		    adapter_.setTopGlyph(device);
		    part_.needResize();
		    return true;
	    }

	    return super.handleEvent(event);
	}
}
