package sgraphics.widget;

// Copyright (c) 1996    Michael A. Jones
// Copyright (c) 1997    Bill Petheram

import sgraphics.*;
import java.awt.*;

/**
 * A class that allows an awt text area to be used as a glyph.
 */
public class TextAreaGlyph extends TextArea implements Viewer, Widget, Glyph {
    private WidgetImpl impl_ = new WidgetImpl(this);

    /**
     * Constructs a new TextArea.
     */
    public TextAreaGlyph () {
	    super();
    }

    /**
     * Constructs a new TextArea with the specified number of rows and columns.
     * @param rows the number of rows
     * @param cols the number of columns
     */
    public TextAreaGlyph (int rows, int cols) {
        super(rows, cols);
    }

    /**
     * Constructs a new TextArea with the specified text displayed.
     * @param text the text to be displayed
     */
    public TextAreaGlyph (String text) {
        super(text);
    }

    /**
     * Constructs a new TextArea with the specified text and number of rows
     * and columns.
     * @param text the text to be displayed
     * @param rows the number of rows
     * @param cols the number of cols
     */
    public TextAreaGlyph (String text, int rows, int cols) {
        super(text, rows, cols);
    }

    public void disconnected () {
        impl_.disconnected();
    }

    public Requirements requirements () {
        return impl_.requirements();
    }

	public void allocate (Allocation allocation) {
	    impl_.allocate(allocation);
	}

    // Forward the rest of the calls.

	public void setParent (Glyph parent) {
		impl_.setParent(parent);
	}

	public Glyph getParentGlyph () {
		return impl_.getParentGlyph();
	}

    public void setCallback (ViewerCallback callback) {
        impl_.setCallback(callback);;
    }

    public void removeCallback () {
        impl_.removeCallback();
    }

	public void pick (Picker pick) {
	    impl_.pick(pick);
	}

	public boolean processPick(Picker pick, GraphicsEvent event) {
	    return impl_.processPick(pick, event);
	}

	public boolean handleEvent (GraphicsEvent event) {
        return false;
    }

	public Glyph body () {
		return impl_.body();
	}

	public void setBody (Glyph body) {
	    impl_.setBody(body);
	}

	public void append (Glyph glyph) {
	    impl_.append(glyph);
	}

	public void prepend (Glyph glyph) {
	    impl_.prepend(glyph);
	}

	public void replace (int position, Glyph glyph) {
	    impl_.replace(position, glyph);
	}

	public void swap (int position1, int position2) {
	    impl_.swap(position1, position2);
	}

	public Glyph getChild (int pos) {
	    return impl_.getChild(pos);
	}

	public void empty () {
	    impl_.empty();
	}

	public int count () {
	    return impl_.count();
	}

	public void grab (Viewer target) {
        impl_.grab(target);
	}

	public void ungrab () {
	    impl_.ungrab();
	}

	public void needRedraw () {
        impl_.needRedraw();
	}

	public void needRedraw (Area area) {
        impl_.needRedraw(area);
	}

	public void needResize () {
	    impl_.needResize();
	}

	public void draw (Painter painter) {
	    impl_.draw(painter);
	}

	public SgraphicsAdapter getSgraphicsAdapter () {
	    return impl_.getSgraphicsAdapter();
	}
}
