package sgraphics.wrapper;

// Copyright (c) 1996    Michael A. Jones

import sgraphics.*;
import java.awt.*;

/**
 * Background draws background color before calling draw() on its child.
 */
public class Background extends MonoGlyph {
    private Color color_;
    private Allocation allocation_;
    private boolean threeD_;
    private boolean raised_;

    /**
     * @param child the child glyph.
     * @param color the background color.
     */
    public Background (Glyph child, Color color) {
        setBody(child);
        color_ = color;
        threeD_ = false;
        raised_ = false;
    }

    /**
     * @param child the child glyph.
     * @param color the background color.
     * @param threeD make the background three dimensional if true.
     * @param raised the background sticks out if true, or sticks in if false.
     */
    public Background (Glyph g, Color color, boolean threeD, boolean raised) {
        setBody(g);
        color_ = color;
        threeD_= threeD;
        raised_ = raised;
    }

    public void setColor (Color color) {
        color_ = color;
        needRedraw();
    }

    public Color getColor () {
        return color_;
    }

    public void allocate (Allocation allocation) {
        allocation_ = allocation;
        super.allocate(allocation);
    }

    public void draw (Painter painter) {
		if (allocation_ != null) {
			BoundingSpan xSpan = allocation_.allocation.span(Area.xAxis);
			BoundingSpan ySpan = allocation_.allocation.span(Area.yAxis);
			painter.setColor(color_);
			if (threeD_)
			    painter.fill3DRect(xSpan.begin, ySpan.begin, xSpan.length, ySpan.length, raised_);
			else
			    painter.fillRect(xSpan.begin, ySpan.begin, xSpan.length, ySpan.length);
		}
        super.draw(painter);
    }
}