package sgraphics.wrapper;

// Copyright (c) 1996    Michael A. Jones

import sgraphics.*;
import java.awt.*;

/**
 * Border draws a three dimensional border around a child.
 */
public class Border extends MonoGlyph {
    private Color highlightColor_;
    private Color shadowColor_;
    private Allocation allocation_;
	private float size_;

    /**
     * @param child the child glyph.
     * @param highlight the color of the top and the left side of the child.
     * @param shadow the color of the bottom and the right side of the child.
     */
    public Border (Glyph child, Color highlight, Color shadow) {
        setBody(child);
        highlightColor_ = highlight;
        shadowColor_ = shadow;
		size_ = 1F;
    }

    /**
     * @param child the child glyph.
     * @param highlight the color of the top and the left side of the child.
     * @param shadow the color of the bottom and the right side of the child.
	 * @param size teh size of the border.
     */
    public Border (Glyph child, Color highlight, Color shadow, float size) {
        setBody(child);
        highlightColor_ = highlight;
        shadowColor_ = shadow;
		size_ = size;
	}

	/**
	 * Revers the highlight and shadow colors.
	 */
	public void reverseColors () {
		Color color = highlightColor_;
		highlightColor_ = shadowColor_;
		shadowColor_ = color;
	}

	public Requirements requirements () {
		Requirements r = super.requirements();

		// Enlarge the requirements.
		Requirements newRequirements = new Requirements();
		newRequirements.x.defined = r.x.defined;
		newRequirements.x.natural = r.x.natural + size_ * 2;
		newRequirements.x.minimum = r.x.minimum;
		newRequirements.x.maximum = r.x.maximum;
		newRequirements.x.align = r.x.align;
		newRequirements.y.defined = r.y.defined;
		newRequirements.y.natural = r.y.natural + size_ * 2;
		newRequirements.y.minimum = r.y.minimum;
		newRequirements.y.maximum = r.y.maximum;
		newRequirements.y.align = r.y.align;
		return newRequirements;
	}

    public void allocate (Allocation allocation) {
        allocation_ = allocation;
		Area area = allocation_.allocation;
		BoundingSpan xSpan = area.span(Axis.xAxis);
		BoundingSpan ySpan = area.span(Axis.yAxis);

		// Reduce the allocation.
		Allocation reducedAllocation = new Allocation();
		reducedAllocation.allocation = new Area (xSpan.begin + size_, ySpan.begin + size_, xSpan.align, xSpan.end - size_, ySpan.end - size_, ySpan.align);
        super.allocate(reducedAllocation);
    }

    public void draw (Painter painter) {
		if (allocation_ != null) {
			BoundingSpan xSpan = allocation_.allocation.span(Area.xAxis);
			BoundingSpan ySpan = allocation_.allocation.span(Area.yAxis);
			for (float layer = 0F; layer < size_; layer += 0.5F) {
				painter.setColor(highlightColor_);
				painter.drawLine(xSpan.begin + layer, ySpan.begin + layer, xSpan.end - layer, ySpan.begin + layer);
				painter.drawLine(xSpan.begin + layer, ySpan.begin + layer, xSpan.begin + layer, ySpan.end - layer);
				painter.setColor(shadowColor_);
				painter.drawLine(xSpan.end - layer, ySpan.begin + 1 + layer, xSpan.end - layer, ySpan.end - layer);
				painter.drawLine(xSpan.begin + 1 + layer, ySpan.end - layer, xSpan.end - layer, ySpan.end - layer);
			}
		}
        super.draw(painter);
    }
}
