package sgraphics.wrapper;

// Copyright (c) 1996    Michael A. Jones

import sgraphics.*;
import sgraphics.util.*;
import java.awt.*;

/**
 * Border draws a recessed border around a child.
 */
public class Outline extends MonoGlyph {
    private Color highlightColor_;
    private Color shadowColor_;
    private Allocation allocation_;

    /**
     * @param child the child glyph.
     * @param highlight the color of the top and the left side of the child.
     * @param shadow the color of the bottom and the right side of the child.
     */
    public Outline (Color highlight, Color shadow) {
        highlightColor_ = highlight;
        shadowColor_ = shadow;
    }

    public void allocate (Allocation allocation) {
        super.allocate(allocation);
        allocation_ = allocation;
    }

    public void draw (Painter painter) {
		if (allocation_ != null) {
			BoundingSpan xSpan = allocation_.allocation.span(Area.xAxis);
			BoundingSpan ySpan = allocation_.allocation.span(Area.yAxis);
			float xLen = 0;
			float yLen = 0;
			Sgraphics s = new Sgraphics();
			if (Sgraphics.resolutionIndependent) {
			    // Make the length even number of pixels to make sure the lines
			    // draw properly.
			    xLen = s.convertHorizontal((s.convertHorizontal(xSpan.length) / 2) * 2);
			    yLen = s.convertHorizontal((s.convertHorizontal(ySpan.length) / 2) * 2);
			}
			else {
			    xLen = xSpan.length;
			    yLen = ySpan.length;
			}
			painter.setColor(shadowColor_);
			painter.drawRect(xSpan.begin + 1.0F, ySpan.begin + 1.0F, xLen, yLen);
			painter.setColor(highlightColor_);
			painter.drawRect(xSpan.begin, ySpan.begin, xLen, yLen);
		}
        super.draw(painter);
    }
}
